# -*- coding: utf-8 -*-
# Generated by Django 1.10b1 on 2016-12-15 05:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('main', '0003_auto_20160612_0933'),
    ]

    operations = [
        migrations.AddField(
            model_name='musician',
            name='active',
            field=models.BooleanField(default=True),
        ),
    ]
